#!/bin/bash

# Quote character for using in -pexec commands:
q='"'

# Date command, in case you want to use the $DATE variable in your plot titles
DATE=`date +"%F %R"`

# -quiet flag in case you don't want the Xmgr GUI to be shown at all
if [ $# -ge 1 ]; then if [ $1 == "-quiet" ]; then QUIET="-hardcopy"; else QUIET=""; fi; fi

xmgr.x -free -noask -eps \
  -printfile ".eps" \
  -pexec "title ${q}${q}" \
  -pexec "subtitle ${q}${q}" \
  -pexec "xaxis label ${q}${q}" \
  -pexec "yaxis label ${q}${q}" \
  -block  -bxy : -pexec "legend string 0 ${q}${q}" \
  -block  -bxy : -pexec "legend string 1 ${q}${q}" \
  -pexec "autoscale" \
  -pexec "legend on" -pexec "legend x1 0.25" -pexec "legend y1 0.75" \
  -pexec "view xmin 0.2" -pexec "view xmax 0.8" -pexec "view ymin 0.2" -pexec "view ymax 0.8" \
  -pexec "frame linewidth 4" -pexec "sets linewidth 3" \
  -pexec "xaxis tick major linewidth 3" -pexec "xaxis tick minor linewidth 2" \
  -pexec "yaxis tick major linewidth 3" -pexec "yaxis tick minor linewidth 2" \
  -device 2 -pexec "hardcopy" $QUIET \
&

# Xmgr command-line and -pexec notes:
#
# 1) Setting line styles:
#
#    None:        -pexec "s0 linestyle 0" \
#    Solid line:  -pexec "s0 linestyle 1" \
#    Dotted line: -pexec "s0 linestyle 2" \
#    Dashed line: -pexec "s0 linestyle 3" \
#    Long Dashed: -pexec "s0 linestyle 4" \
#    Dot-dashed:  -pexec "s0 linestyle 5" \
#
# 2) Xmgr color codes:
#
#    white = 0    blue   = 4   violet  =  8   indigo = 12
#    black = 1    yellow = 5   cyan    =  9   maroon = 13
#    red   = 2    brown  = 6   magenta = 10   turqse = 14
#    green = 3    gray   = 7   orange  = 11   green4 = 15
#
# 3) Setting line colors:
#
#    -pexec "s0 color 1" \
#
# 4) Setting symbols:
#
#    -pexec "s0 symbol 2" -pexec "s0 symbol fill 1" -pexec "s0 symbol size 0.7" -pexec "s0 symbol skip 200" \
#
#    where available symbols are:
#    No symbol      = 0    (add more in the future if necessary)
#    Dot            = 1
#    Circle         = 2
#    Diamond        = 3
#    Triangle up    = 4
#    Triangle down  = 5
#    Triangle right = 6
#    Plus           = 7
#    X              = 8
#    Star           = 9
#
#    Fill codes: 0: transparent, 1: filled with symbol foreground color, 2: filled with background color
#
# 5) Legend formatting:
#
#    -pexec "legend box on" -pexec "legend box linewidth 2" -pexec "legend box fill on" -pexec "legend char size 0.7" \
#
# 6) Controlling world scaling and tick spacing:
#
#    -noauto xy -pexec "world 0, 0, 75, 60" \
#    -pexec "xaxis tick major 25" -pexec "xaxis tick minor 5" \
#    -pexec "yaxis tick major 10" -pexec "yaxis tick minor 2" \
#
# 7) Writing text strings on a graph:
#
#    -pexec "with string" -pexec "string on" -pexec "string 0.25, 0.35" \
#    -pexec "string def ${q}Put text here${q}" \
#
# Online Xmgr command reference: http://plasma-gate.weizmann.ac.il/Xmgr/doc/commands.html
